@@ -13,13 +13,13 @@ use Carp qw(croak);
 #use List::Util "reduce";
 #use vars qw($a $b);
 
-our $VERSION = '0.0.2'; # VERSION
+our $VERSION = '0.0.3'; # VERSION
 # ABSTRACT: Interact with LogicBoxes reseller API
 
 with "WWW::LogicBoxes::Role::Commands";
 
 # Supported Response Types:
-my @response_types = qw(xml json);
+my @response_types = qw(xml json xml_simple);
 subtype "LogicBoxesResponseType"
 	=> as "Str",
 	=> where {
@@ -83,10 +83,11 @@ sub _make_query_string {
 	$api_method =~ s/_/-/g;
 	$api_method =~ s/__/\//g;
 
+	my $response_type = ($self->response_type eq 'xml_simple') ? 'xml' : $self->response_type;
 	my $queryURI = $self->_base_uri
 		. "api/"		. $api_class
 		. "/" 			. $api_method
-		. "." 			. $self->response_type
+		. "." 			. $response_type
 		. "?auth-userid=" 	. uri_escape($self->username)
 		. "&auth-password=" 	. uri_escape($self->password)
 		. "&"			. _build_get_args($opts);
@@ -158,6 +159,8 @@ response_type is also an object argument that dictates the format in which the r
 
 =item * json
 
+=item * xml_simple
+
 =back
 
 =head2 Suggest Domains (and many others)
